@@ -5,12 +5,13 @@ from validictory.validator import (SchemaValidator, FieldValidationError,
 
 __all__ = ['validate', 'SchemaValidator', 'FieldValidationError',
            'ValidationError', 'SchemaError']
-__version__ = '0.9.1'
+__version__ = '0.9.2'
 
 
 def validate(data, schema, validator_cls=SchemaValidator,
              format_validators=None, required_by_default=True,
-             blank_by_default=False, disallow_unknown_properties=False):
+             blank_by_default=False, disallow_unknown_properties=False,
+             apply_default_to_data=False):
     '''
     Validates a parsed json document against the provided schema. If an
     error is found a :class:`ValidationError` is raised.
@@ -27,9 +28,11 @@ def validate(data, schema, validator_cls=SchemaValidator,
         ``required`` schema attribute False by default.
     :param disallow_unknown_properties: defaults to False, set to True to
         disallow properties not listed in the schema definition
+    :param apply_default_to_data: defaults to False, set to True to modify the
+        data in case the schema definition includes a "default" property
     '''
     v = validator_cls(format_validators, required_by_default, blank_by_default,
-                      disallow_unknown_properties)
+                      disallow_unknown_properties, apply_default_to_data)
     return v.validate(data, schema)
 
 if __name__ == '__main__':
