@@ -102,17 +102,26 @@ class SchemaValidator(object):
         schema attribute True by default.
     :param disallow_unknown_properties: defaults to False, set to True to
         disallow properties not listed in the schema definition
+    :param apply_default_to_data: defaults to False, set to True to modify the
+        data in case the schema definition includes a "default" property
     '''
 
     def __init__(self, format_validators=None, required_by_default=True,
-                 blank_by_default=False, disallow_unknown_properties=False):
-        if format_validators is None:
-            format_validators = DEFAULT_FORMAT_VALIDATORS.copy()
+                 blank_by_default=False, disallow_unknown_properties=False,
+                 apply_default_to_data=False):
 
-        self._format_validators = format_validators
+        # add the default format validators
+        for key, value in DEFAULT_FORMAT_VALIDATORS:
+            self.register_format_validator(key, value)
+
+        # register any custom format validators if they were provided
+        if format_validators:
+            for key, value in format_validators:
+                self.register_format_validator(key, value)
         self.required_by_default = required_by_default
         self.blank_by_default = blank_by_default
         self.disallow_unknown_properties = disallow_unknown_properties
+        self.apply_default_to_data = apply_default_to_data
 
     def register_format_validator(self, format_name, format_validator_fun):
         self._format_validators[format_name] = format_validator_fun
@@ -130,7 +139,8 @@ class SchemaValidator(object):
         return type(val) == bool
 
     def validate_type_object(self, val):
-        return isinstance(val, Mapping)
+        return isinstance(val, Mapping) or (hasattr(val, 'keys')
+                                            and hasattr(val, 'items'))
 
     def validate_type_array(self, val):
         return isinstance(val, (list, tuple))
@@ -348,18 +358,21 @@ class SchemaValidator(object):
         value = x.get(fieldname)
         if isinstance(additionalProperties, (dict, bool)):
             properties = schema.get("properties")
+            patterns = schema["patternProperties"].keys() if 'patternProperties' in schema else []
             if properties is None:
                 properties = {}
             if value is None:
                 value = {}
             for eachProperty in value:
-                if eachProperty not in properties:
+                if eachProperty not in properties and not \
+                   any(re.match(p, eachProperty) for p in patterns):
                     # If additionalProperties is the boolean value False
                     # then we don't accept any additional properties.
                     if (isinstance(additionalProperties, bool) and not
                             additionalProperties):
                         self._error("additional property '%(prop)s' "
-                                    "not defined by 'properties' are not "
+                                    "not defined by 'properties' or "
+                                    "'patternProperties' are not "
                                     "allowed in field '%(fieldname)s'",
                                     None, fieldname, prop=eachProperty)
                     self.__validate(eachProperty, value,
@@ -602,6 +615,20 @@ class SchemaValidator(object):
                     validator(data, fieldname, schema,
                               newschema.get(schemaprop))
 
+            if self.apply_default_to_data and 'default' in schema:
+                try:
+                    self.validate_type(
+                        x={'_ds': schema['default']},
+                        fieldname='_ds',
+                        schema=schema,
+                        fieldtype=schema['type'] if 'type' in schema else None
+                    )
+                except FieldValidationError as exc:
+                    raise SchemaError(exc)
+
+                if not fieldname in data:
+                    data[fieldname] = schema['default']
+
         return data
 
 __all__ = ['SchemaValidator', 'FieldValidationError']
